import { taggedTemplateLiteral as _taggedTemplateLiteral } from '../../../_virtual/_rollupPluginBabelHelpers.js';
import { keyframes, jsx } from '@emotion/core';
import _pt from 'prop-types';
import { MdClose, MdDone, MdWarning } from 'react-icons/md';
import Alert from '../../../node_modules/@reach/alert/dist/alert.esm.esm.js';

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  100% {\n     transform: perspective(1000px) rotateX(0);\n  }\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
var toastEntryAnimation = keyframes(_templateObject());
var TOAST_MIN_HEIGHT = "3rem";

var baseCss = function baseCss(theme) {
  return {
    alignItems: "center",
    animation: "".concat(toastEntryAnimation, " 0.5s 0.25s ease forwards"),
    background: theme.colors.grey[90],
    borderLeft: "".concat(theme.space[3], " solid ").concat(theme.colors.green[50]),
    borderRadius: "".concat(theme.radii[2], " ").concat(theme.radii[2], " 0 0"),
    color: theme.colors.green[5],
    display: "flex",
    fontSize: theme.fontSizes[1],
    minHeight: TOAST_MIN_HEIGHT,
    maxWidth: "calc(100% - (".concat(theme.space[7], " * 2))"),
    paddingLeft: theme.space[4],
    transform: "perspective(1000px) rotateX(90deg)",
    transformOrigin: "bottom center",
    "&:not(:first-of-type)": {
      borderRadius: theme.radii[2],
      marginBottom: theme.space[1]
    }
  };
};

var baseToneStyles = {
  SUCCESS: function SUCCESS(theme) {
    return {
      borderLeftColor: theme.colors.green[50]
    };
  },
  DANGER: function DANGER(theme) {
    return {
      borderLeftColor: theme.colors.red[60]
    };
  }
};

var iconCss = function iconCss(_theme) {
  return {
    height: "auto",
    width: "calc(".concat(TOAST_MIN_HEIGHT, " * 0.4)")
  };
};

var messageCss = function messageCss(theme) {
  return {
    lineHeight: theme.lineHeights.solid,
    marginTop: 0,
    marginBottom: 0,
    marginRight: theme.space[2],
    marginLeft: theme.space[3]
  };
};

var statusCss = function statusCss(theme) {
  return {
    display: "flex",
    alignItems: "center",
    color: theme.colors.green[50]
  };
};

var statusToneStyles = {
  SUCCESS: function SUCCESS(theme) {
    return {
      color: theme.colors.green[50]
    };
  },
  DANGER: function DANGER(theme) {
    return {
      color: theme.colors.red[60]
    };
  }
};

var closeButtonCss = function closeButtonCss(theme) {
  return {
    background: "none",
    border: "none",
    color: theme.colors.grey[40],
    cursor: "pointer",
    display: "flex",
    alignItems: "center",
    justifyContent: "center",
    height: TOAST_MIN_HEIGHT,
    width: TOAST_MIN_HEIGHT
  };
};

var ToastIconByTone = {
  SUCCESS: MdDone,
  DANGER: MdWarning
};
function Toast(_ref) {
  var message = _ref.message,
      tone = _ref.tone,
      closeButtonLabel = _ref.closeButtonLabel,
      onClose = _ref.onClose;
  var IconComponent = ToastIconByTone[tone];

  var toastCss = function toastCss(theme) {
    return [baseCss(theme), baseToneStyles[tone](theme)];
  };

  var statusFinalCss = function statusFinalCss(theme) {
    return [statusCss(theme), statusToneStyles[tone](theme)];
  };

  return jsx(Alert, {
    css: toastCss,
    "data-testid": "toast",
    type: tone === "DANGER" ? "assertive" : "polite"
  }, jsx("span", {
    css: statusFinalCss
  }, jsx(IconComponent, {
    css: iconCss
  })), jsx("div", {
    css: messageCss
  }, message), jsx("button", {
    css: closeButtonCss,
    type: "button",
    onClick: onClose,
    "aria-label": closeButtonLabel
  }, jsx(MdClose, null)));
}
Toast.propTypes = {
  message: _pt.node.isRequired,
  onClose: _pt.func.isRequired,
  closeButtonLabel: _pt.string.isRequired
};
Toast.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "Toast",
  "props": {
    "message": {
      "required": true,
      "tsType": {
        "name": "ReactReactNode",
        "raw": "React.ReactNode"
      },
      "description": ""
    },
    "onClose": {
      "required": true,
      "tsType": {
        "name": "signature",
        "type": "function",
        "raw": "() => void",
        "signature": {
          "arguments": [],
          "return": {
            "name": "void"
          }
        }
      },
      "description": ""
    },
    "closeButtonLabel": {
      "required": true,
      "tsType": {
        "name": "string"
      },
      "description": ""
    },
    "tone": {
      "required": true,
      "tsType": {
        "name": "ToastTone"
      },
      "description": ""
    }
  }
};

if (typeof STORYBOOK_REACT_CLASSES !== "undefined") {
  STORYBOOK_REACT_CLASSES["src/components/Toast/Toast.tsx"] = {
    name: "Toast",
    docgenInfo: Toast.__docgenInfo,
    path: "src/components/Toast/Toast.tsx"
  };
}

export { Toast };
//# sourceMappingURL=Toast.esm.js.map
